@@ -2,7 +2,7 @@
 # :Project:   python-rapidjson -- reST tables writer tool
 # :Author:    Lele Gaifax <lele@metapensiero.it>
 # :License:   MIT License
-# :Copyright: © 2017, 2018 Lele Gaifax
+# :Copyright: © 2017, 2018, 2020 Lele Gaifax
 #
 
 # Assume we did::
@@ -95,6 +95,8 @@ def dumps_and_loads(benchmarks):
                   'rapidjson_c',
                   'rapidjson_nn_f',
                   'rapidjson_nn_c',
+                  'hyperjson',
+                  'orjson',
                   'ujson',
                   'simplejson',
                   'stdlib json',
@@ -103,14 +105,18 @@ def dumps_and_loads(benchmarks):
                  r'``Encoder()``\ [2]_',
                  r'``dumps(n)``\ [3]_',
                  r'``Encoder(n)``\ [4]_',
-                 r'ujson\ [5]_',
-                 r'simplejson\ [6]_',
-                 r'stdlib\ [7]_',
-                 r'yajl\ [8]_')
-    d_headers = (r'``loads()``\ [9]_',
-                 r'``Decoder()``\ [10]_',
-                 r'``loads(n)``\ [11]_',
-                 r'``Decoder(n)``\ [12]_',
+                 r'hyperjson\ [5]_',
+                 r'orjson\ [6]_',
+                 r'ujson\ [7]_',
+                 r'simplejson\ [8]_',
+                 r'stdlib\ [9]_',
+                 r'yajl\ [10]_')
+    d_headers = (r'``loads()``\ [11]_',
+                 r'``Decoder()``\ [12]_',
+                 r'``loads(n)``\ [13]_',
+                 r'``Decoder(n)``\ [14]_',
+                 r'hyperjson',
+                 r'orjson',
                  r'ujson',
                  r'simplejson',
                  r'stdlib',
@@ -123,14 +129,16 @@ def dumps_and_loads(benchmarks):
         '.. [2] ``rapidjson.Encoder()``',
         '.. [3] ``rapidjson.dumps(number_mode=NM_NATIVE)``',
         '.. [4] ``rapidjson.Encoder(number_mode=NM_NATIVE)``',
-        '.. [5] `ujson 1.35 <https://pypi.org/pypi/ujson/1.35>`__',
-        '.. [6] `simplejson 3.16.0 <https://pypi.org/pypi/simplejson/3.16.0>`__',
-        '.. [7] Python %d.%d.%d standard library ``json``' % sys.version_info[:3],
-        '.. [8] `yajl 0.3.5 <https://pypi.org/pypi/yajl/0.3.5>`__',
-        '.. [9] ``rapidjson.loads()``',
-        '.. [10] ``rapidjson.Decoder()``',
-        '.. [11] ``rapidjson.loads(number_mode=NM_NATIVE)``',
-        '.. [12] ``rapidjson.Decoder(number_mode=NM_NATIVE)``']
+        '.. [5] `hyperjson 0.2.4 <https://pypi.org/project/hyperjson/0.2.4/>`__',
+        '.. [6] `orjson 2.5.0 <https://pypi.org/project/orjson/2.5.0/>`__',
+        '.. [7] `ujson 1.35 <https://pypi.org/pypi/ujson/1.35>`__',
+        '.. [8] `simplejson 3.17.0 <https://pypi.org/pypi/simplejson/3.17.0>`__',
+        '.. [9] Python %d.%d.%d standard library ``json``' % sys.version_info[:3],
+        '.. [10] `yajl 0.3.5 <https://pypi.org/pypi/yajl/0.3.5>`__',
+        '.. [11] ``rapidjson.loads()``',
+        '.. [12] ``rapidjson.Decoder()``',
+        '.. [13] ``rapidjson.loads(number_mode=NM_NATIVE)``',
+        '.. [14] ``rapidjson.Decoder(number_mode=NM_NATIVE)``']
 
     comparison = Comparison(contenders, benchmarks)
 
@@ -154,7 +162,7 @@ def ascii_vs_utf8(benchmarks):
                ('simplejson', 'sj'),
                ('stdlib json', 'json'))
     contenders = ['%s %s' % (e[0], k) for e in engines for k in ('ascii', 'utf8')]
-    i = 12
+    i = 14
     s_headers = []
     footnotes = []
     for e in engines:
